summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authormontezdesousa <79287829+montezdesousa@users.noreply.github.com>2024-04-30 13:42:31 +0100
committerGitHub <noreply@github.com>2024-04-30 12:42:31 +0000
commitcc15a770daa013f61cf8cf42218d877513ad64be (patch)
tree86e87c4e4ae0d5e39a444e5cb2e30040715779ec
parent5f4ee569792283c22fc4936e4d3ff42b62034071 (diff)
[Feature] - Rename terminal folder (#6349)
* rename terminal folder * docstring * Rename to openbb_cli * rename constant * rename .his file * pyproject.toml * Update pre-commit and remove docker-build.yml
-rw-r--r--.github/workflows/docker-build.yml48
-rw-r--r--.gitignore6
-rw-r--r--.pre-commit-config.yaml1
-rw-r--r--cli/CONTRIBUTING.md (renamed from openbb_terminal/CONTRIBUTING.md)0
-rw-r--r--cli/README.md (renamed from openbb_terminal/README.md)0
-rw-r--r--cli/openbb_cli/__init__.py (renamed from openbb_terminal/openbb_terminal/__init__.py)0
-rw-r--r--cli/openbb_cli/argparse_translator/__init__.py (renamed from openbb_terminal/openbb_terminal/argparse_translator/__init__.py)0
-rw-r--r--cli/openbb_cli/argparse_translator/argparse_class_processor.py (renamed from openbb_terminal/openbb_terminal/argparse_translator/argparse_class_processor.py)2
-rw-r--r--cli/openbb_cli/argparse_translator/argparse_translator.py (renamed from openbb_terminal/openbb_terminal/argparse_translator/argparse_translator.py)0
-rw-r--r--cli/openbb_cli/argparse_translator/obbject_registry.py (renamed from openbb_terminal/openbb_terminal/argparse_translator/obbject_registry.py)0
-rw-r--r--cli/openbb_cli/assets/i18n/en.yml (renamed from openbb_terminal/openbb_terminal/assets/i18n/en.yml)2
-rw-r--r--cli/openbb_cli/assets/routines/routine_example.openbb (renamed from openbb_terminal/openbb_terminal/assets/routines/routine_example.openbb)0
-rw-r--r--cli/openbb_cli/assets/styles/default/Consolas.ttf (renamed from openbb_terminal/openbb_terminal/assets/styles/default/Consolas.ttf)bin358460 -> 358460 bytes
-rw-r--r--cli/openbb_cli/assets/styles/default/dark.mpfstyle.json (renamed from openbb_terminal/openbb_terminal/assets/styles/default/dark.mpfstyle.json)0
-rw-r--r--cli/openbb_cli/assets/styles/default/dark.mplrc.json (renamed from openbb_terminal/openbb_terminal/assets/styles/default/dark.mplrc.json)0
-rw-r--r--cli/openbb_cli/assets/styles/default/dark.mplstyle (renamed from openbb_terminal/openbb_terminal/assets/styles/default/dark.mplstyle)0
-rw-r--r--cli/openbb_cli/assets/styles/default/dark.pltstyle.json (renamed from openbb_terminal/openbb_terminal/assets/styles/default/dark.pltstyle.json)0
-rw-r--r--cli/openbb_cli/assets/styles/default/dark.richstyle.json (renamed from openbb_terminal/openbb_terminal/assets/styles/default/dark.richstyle.json)0
-rw-r--r--cli/openbb_cli/assets/styles/default/light.mpfstyle.json (renamed from openbb_terminal/openbb_terminal/assets/styles/default/light.mpfstyle.json)0
-rw-r--r--cli/openbb_cli/assets/styles/default/light.mplrc.json (renamed from openbb_terminal/openbb_terminal/assets/styles/default/light.mplrc.json)0
-rw-r--r--cli/openbb_cli/assets/styles/default/light.mplstyle (renamed from openbb_terminal/openbb_terminal/assets/styles/default/light.mplstyle)0
-rw-r--r--cli/openbb_cli/assets/styles/default/light.pltstyle.json (renamed from openbb_terminal/openbb_terminal/assets/styles/default/light.pltstyle.json)0
-rw-r--r--cli/openbb_cli/assets/styles/default/light.richstyle.json (renamed from openbb_terminal/openbb_terminal/assets/styles/default/light.richstyle.json)0
-rw-r--r--cli/openbb_cli/assets/styles/default/tables.pltstyle.json (renamed from openbb_terminal/openbb_terminal/assets/styles/default/tables.pltstyle.json)0
-rw-r--r--cli/openbb_cli/assets/styles/user/openbb.richstyle.json (renamed from openbb_terminal/openbb_terminal/assets/styles/user/openbb.richstyle.json)0
-rw-r--r--cli/openbb_cli/cli.py20
-rw-r--r--cli/openbb_cli/config/__init__.py (renamed from openbb_terminal/openbb_terminal/config/__init__.py)0
-rw-r--r--cli/openbb_cli/config/completer.py (renamed from openbb_terminal/openbb_terminal/config/completer.py)0
-rw-r--r--cli/openbb_cli/config/console.py (renamed from openbb_terminal/openbb_terminal/config/console.py)10
-rw-r--r--cli/openbb_cli/config/constants.py (renamed from openbb_terminal/openbb_terminal/config/constants.py)8
-rw-r--r--cli/openbb_cli/config/menu_text.py (renamed from openbb_terminal/openbb_terminal/config/menu_text.py)2
-rw-r--r--cli/openbb_cli/config/setup.py (renamed from openbb_terminal/openbb_terminal/config/setup.py)15
-rw-r--r--cli/openbb_cli/config/style.py (renamed from openbb_terminal/openbb_terminal/config/style.py)2
-rw-r--r--cli/openbb_cli/controllers/base_controller.py (renamed from openbb_terminal/openbb_terminal/controllers/base_controller.py)31
-rw-r--r--cli/openbb_cli/controllers/base_platform_controller.py (renamed from openbb_terminal/openbb_terminal/controllers/base_platform_controller.py)15
-rw-r--r--cli/openbb_cli/controllers/choices.py (renamed from openbb_terminal/openbb_terminal/controllers/choices.py)14
-rw-r--r--cli/openbb_cli/controllers/cli_controller.py (renamed from openbb_terminal/openbb_terminal/controllers/terminal_controller.py)87
-rw-r--r--cli/openbb_cli/controllers/feature_flags_controller.py (renamed from openbb_terminal/openbb_terminal/controllers/feature_flags_controller.py)14
-rw-r--r--cli/openbb_cli/controllers/hub_service.py (renamed from openbb_terminal/openbb_terminal/controllers/hub_service.py)5
-rw-r--r--cli/openbb_cli/controllers/platform_controller_factory.py (renamed from openbb_terminal/openbb_terminal/controllers/platform_controller_factory.py)4
-rw-r--r--cli/openbb_cli/controllers/script_parser.py (renamed from openbb_terminal/openbb_terminal/controllers/script_parser.py)3
-rw-r--r--cli/openbb_cli/controllers/utils.py (renamed from openbb_terminal/openbb_terminal/controllers/utils.py)33
-rw-r--r--cli/openbb_cli/models/settings.py (renamed from openbb_terminal/openbb_terminal/models/settings.py)5
-rw-r--r--cli/openbb_cli/session.py (renamed from openbb_terminal/openbb_terminal/session.py)16
-rw-r--r--cli/poetry.lock (renamed from openbb_terminal/poetry.lock)0
-rw-r--r--cli/pyproject.toml (renamed from openbb_terminal/pyproject.toml)8
-rw-r--r--cli/tests/__init__.py (renamed from openbb_terminal/tests/__init__.py)0
-rw-r--r--frontend-components/plotly/package.json2
-rw-r--r--frontend-components/tables/package.json2
-rw-r--r--openbb_terminal/openbb_terminal/cli.py20
-rw-r--r--ruff.toml8
51 files changed, 162 insertions, 221 deletions
diff --git a/.github/workflows/docker-build.yml b/.github/workflows/docker-build.yml
deleted file mode 100644
index 6e69b5d9a6c..00000000000
--- a/.github/workflows/docker-build.yml
+++ /dev/null
@@ -1,48 +0,0 @@
-name: Build and Publish Docker
-
-on: workflow_dispatch
-
-jobs:
- publish-image:
- runs-on: ubuntu-latest
- env:
- OPENBBTERMINAL_DOCKER_GITHUB_REPOSITORY: ${{ github.repository }}
- OPENBB_LOGGING_APP_NAME: "gst_docker"
-
- steps:
- - name: Checkout Code
- uses: actions/checkout@v3
-
- - name: Login to GitHub Container Registry
- uses: docker/login-action@v2
- with:
- registry: ghcr.io
- username: ${{ github.actor }}
- password: ${{ secrets.GITHUB_TOKEN }}
-
- - name: Setup commit hash
- run: |
- echo "OPENBB_LOGGING_COMMIT_HASH=sha:$(git rev-parse --short=8 "$GITHUB_SHA")" >> $GITHUB_ENV
-
- - name: Build env file
- run: |
- echo "OPENBB_LOGGING_APP_NAME='${OPENBB_LOGGING_APP_NAME}'" > openbb_terminal/.env
- echo "OPENBB_LOGGING_COMMIT_HASH='${OPENBB_LOGGING_COMMIT_HASH}'" >> openbb_terminal/.env
- cat openbb_terminal/.env
-
- - name: Building the Docker image
- run: |
- source build/docker/compose.env
- source build/docker/build.sh
- echo "OPENBBTERMINAL_DOCKER_POETRY_IMAGE=$OPENBBTERMINAL_DOCKER_POETRY_IMAGE" >> $GITHUB_ENV
- echo "OPENBBTERMINAL_DOCKER_POETRY_IMAGE_LATEST=$OPENBBTERMINAL_DOCKER_POETRY_IMAGE_LATEST" >> $GITHUB_ENV
-
- - name: Publishing the Docker image (release version)
- run: |
- docker push "${OPENBBTERMINAL_DOCKER_POETRY_IMAGE}"
- if: startsWith(github.ref, 'refs/heads/main')
-
- - name: Publishing the latest Docker image
- run: |
- docker push "${OPENBBTERMINAL_DOCKER_POETRY_IMAGE_LATEST}"
- if: startsWith(github.ref, 'refs/heads/main')
diff --git a/.gitignore b/.gitignore
index 5160f3f560b..a16c29ef0d3 100644
--- a/.gitignore
+++ b/.gitignore
@@ -40,15 +40,15 @@ lightning_logs/
*/mocked_path
*.pem
-# Terminal
+# CLI
*.pyo
**/dist/*
-build/terminal
+build/cli
build/nsis/app
DMG/*
*.dmg
*.sh
-openbb_terminal/openbb_terminal/assets/styles/user/hub.richstyle.json
+cli/openbb_cli/assets/styles/user/hub.richstyle.json
# Platform
openbb_platform/openbb/package/*
diff --git a/.pre-commit-config.yaml b/.pre-commit-config.yaml
index da3cfd4d3e9..e16417a185e 100644
--- a/.pre-commit-config.yaml
+++ b/.pre-commit-config.yaml
@@ -39,7 +39,6 @@ repos:
"--ignore-words-list=VAI,MIS,shs,gard,te,commun,parana,ro,zar,vie,hel,jewl,zlot,ba,buil,coo,ether,hist,hsi,mape,navagation,operatio,pres,ser,yeld,shold,ist,varian,datas,ake,creat,statics,ket,toke,certi,buidl,ot,fo",
"--quiet-level=2",
"--skip=./**/tests/**,./**/test_*.py,.git,*.css,*.csv,*.html,*.ini,*.ipynb,*.js,*.json,*.lock,*.scss,*.txt,*.yaml,build/pyinstaller/*,./website/config.toml",
- "-x=openbb_terminal/economy/fedreserve_model.py",
"-x=.github/workflows/linting.yml"
]
- repo: local
diff --git a/openbb_terminal/CONTRIBUTING.md b/cli/CONTRIBUTING.md
index 49314e4a8e4..49314e4a8e4 100644
--- a/openbb_terminal/CONTRIBUTING.md
+++ b/cli/CONTRIBUTING.md
diff --git a/openbb_terminal/README.md b/cli/README.md
index 28bcbff336d..28bcbff336d 100644
--- a/openbb_terminal/README.md
+++ b/cli/README.md
diff --git a/openbb_terminal/openbb_terminal/__init__.py b/cli/openbb_cli/__init__.py
index 542734dabf3..542734dabf3 100644
--- a/openbb_terminal/openbb_terminal/__init__.py
+++ b/cli/openbb_cli/__init__.py
diff --git a/openbb_terminal/openbb_terminal/argparse_translator/__init__.py b/cli/openbb_cli/argparse_translator/__init__.py
index e69de29bb2d..e69de29bb2d 100644
--- a/openbb_terminal/openbb_terminal/argparse_translator/__init__.py
+++ b/cli/openbb_cli/argparse_translator/__init__.py
diff --git a/openbb_terminal/openbb_terminal/argparse_translator/argparse_class_processor.py b/cli/openbb_cli/argparse_translator/argparse_class_processor.py
index 74e706e5ebb..6fff39aa18e 100644
--- a/openbb_terminal/openbb_terminal/argparse_translator/argparse_class_processor.py
+++ b/cli/openbb_cli/argparse_translator/argparse_class_processor.py
@@ -4,7 +4,7 @@ from typing import Any, Dict, Optional, Type
# TODO: this needs to be done differently
from openbb_core.app.static.container import Container
-from openbb_terminal.argparse_translator.argparse_translator import (
+from openbb_cli.argparse_translator.argparse_translator import (
ArgparseTranslator,
ReferenceToCustomArgumentsProcessor,
)
diff --git a/openbb_terminal/openbb_terminal/argparse_translator/argparse_translator.py b/cli/openbb_cli/argparse_translator/argparse_translator.py
index 45fa4ce5d6b..45fa4ce5d6b 100644
--- a/openbb_terminal/openbb_terminal/argparse_translator/argparse_translator.py
+++ b/cli/openbb_cli/argparse_translator/argparse_translator.py
diff --git a/openbb_terminal/openbb_terminal/argparse_translator/obbject_registry.py b/cli/openbb_cli/argparse_translator/obbject_registry.py
index cb1643747b3..cb1643747b3 100644
--- a/openbb_terminal/openbb_terminal/argparse_translator/obbject_registry.py
+++ b/cli/openbb_cli/argparse_translator/obbject_registry.py
diff --git a/openbb_terminal/openbb_terminal/assets/i18n/en.yml b/cli/openbb_cli/assets/i18n/en.yml
index beb4013229d..a8d06e45b88 100644
--- a/openbb_terminal/openbb_terminal/assets/i18n/en.yml
+++ b/cli/openbb_cli/assets/i18n/en.yml
@@ -11,7 +11,7 @@ en:
_configure_: Configure your own CLI
_main_menu_: Main menu
settings/_info_: Feature flags
- settings/_settings_: Terminal settings and preferences
+ settings/_settings_: Settings and preferences
settings/retryload: retry misspelled commands with load first
settings/interactive: open dataframes in interactive window
settings/cls: clear console after each command
diff --git a/openbb_terminal/openbb_terminal/assets/routines/routine_example.openbb b/cli/openbb_cli/assets/routines/routine_example.openbb
index 72c7fa574aa..72c7fa574aa 100644
--- a/openbb_terminal/openbb_terminal/assets/routines/routine_example.openbb
+++ b/cli/openbb_cli/assets/routines/routine_example.openbb
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/Consolas.ttf b/cli/openbb_cli/assets/styles/default/Consolas.ttf
index 556d2fd5d2e..556d2fd5d2e 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/Consolas.ttf
+++ b/cli/openbb_cli/assets/styles/default/Consolas.ttf
Binary files differ
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/dark.mpfstyle.json b/cli/openbb_cli/assets/styles/default/dark.mpfstyle.json
index 069d22e4369..069d22e4369 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/dark.mpfstyle.json
+++ b/cli/openbb_cli/assets/styles/default/dark.mpfstyle.json
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/dark.mplrc.json b/cli/openbb_cli/assets/styles/default/dark.mplrc.json
index 0a734353311..0a734353311 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/dark.mplrc.json
+++ b/cli/openbb_cli/assets/styles/default/dark.mplrc.json
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/dark.mplstyle b/cli/openbb_cli/assets/styles/default/dark.mplstyle
index 9c991ad0081..9c991ad0081 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/dark.mplstyle
+++ b/cli/openbb_cli/assets/styles/default/dark.mplstyle
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/dark.pltstyle.json b/cli/openbb_cli/assets/styles/default/dark.pltstyle.json
index f1f75a99fa2..f1f75a99fa2 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/dark.pltstyle.json
+++ b/cli/openbb_cli/assets/styles/default/dark.pltstyle.json
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/dark.richstyle.json b/cli/openbb_cli/assets/styles/default/dark.richstyle.json
index 9590d25b3c9..9590d25b3c9 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/dark.richstyle.json
+++ b/cli/openbb_cli/assets/styles/default/dark.richstyle.json
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/light.mpfstyle.json b/cli/openbb_cli/assets/styles/default/light.mpfstyle.json
index 9f75a73a30f..9f75a73a30f 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/light.mpfstyle.json
+++ b/cli/openbb_cli/assets/styles/default/light.mpfstyle.json
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/light.mplrc.json b/cli/openbb_cli/assets/styles/default/light.mplrc.json
index a7b3d08bcbf..a7b3d08bcbf 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/light.mplrc.json
+++ b/cli/openbb_cli/assets/styles/default/light.mplrc.json
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/light.mplstyle b/cli/openbb_cli/assets/styles/default/light.mplstyle
index 807f6caa752..807f6caa752 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/light.mplstyle
+++ b/cli/openbb_cli/assets/styles/default/light.mplstyle
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/light.pltstyle.json b/cli/openbb_cli/assets/styles/default/light.pltstyle.json
index 6572f11da1a..6572f11da1a 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/light.pltstyle.json
+++ b/cli/openbb_cli/assets/styles/default/light.pltstyle.json
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/light.richstyle.json b/cli/openbb_cli/assets/styles/default/light.richstyle.json
index e09be31a842..e09be31a842 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/light.richstyle.json
+++ b/cli/openbb_cli/assets/styles/default/light.richstyle.json
diff --git a/openbb_terminal/openbb_terminal/assets/styles/default/tables.pltstyle.json b/cli/openbb_cli/assets/styles/default/tables.pltstyle.json
index 69f80ef4d88..69f80ef4d88 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/default/tables.pltstyle.json
+++ b/cli/openbb_cli/assets/styles/default/tables.pltstyle.json
diff --git a/openbb_terminal/openbb_terminal/assets/styles/user/openbb.richstyle.json b/cli/openbb_cli/assets/styles/user/openbb.richstyle.json
index 5d8b5d87e21..5d8b5d87e21 100644
--- a/openbb_terminal/openbb_terminal/assets/styles/user/openbb.richstyle.json
+++ b/cli/openbb_cli/assets/styles/user/openbb.richstyle.json
diff --git a/cli/openbb_cli/cli.py b/cli/openbb_cli/cli.py
new file mode 100644
index 00000000000..c301be893f9
--- /dev/null
+++ b/cli/openbb_cli/cli.py
@@ -0,0 +1,20 @@
+"""OpenBB Platform CLI entry point."""
+
+import sys
+
+from openbb_cli.config.setup import bootstrap
+from openbb_cli.controllers.cli_controller import launch
+
+
+def main():
+ """Use the main entry point for the OpenBB CLI."""
+ bootstrap()
+
+ dev = "--dev" in sys.argv[1:]
+ debug = "--debug" in sys.argv[1:]
+
+ launch(dev, debug)
+
+
+if __name__ == "__main__":
+ main()
diff --git a/openbb_terminal/openbb_terminal/config/__init__.py b/cli/openbb_cli/config/__init__.py
index 96aa4d3b1a8..96aa4d3b1a8 100644
--- a/openbb_terminal/openbb_terminal/config/__init__.py
+++ b/cli/openbb_cli/config/__init__.py
diff --git a/openbb_terminal/openbb_terminal/config/completer.py b/cli/openbb_cli/config/completer.py
index f084c821478..f084c821478 100644
--- a/openbb_terminal/openbb_terminal/config/completer.py
+++ b/cli/openbb_cli/config/completer.py
diff --git a/openbb_terminal/openbb_terminal/config/console.py b/cli/openbb_cli/config/console.py
index 749e40c0a3b..f19904cedc4 100644
--- a/openbb_terminal/openbb_terminal/config/console.py
+++ b/cli/openbb_cli/config/console.py
@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Optional, Tuple
+from typing import TYPE_CHECKING, Any, Dict, Optional, Tuple
from rich import panel
from rich.console import (
@@ -7,10 +7,10 @@ from rich.console import (
)
from rich.text import Text
-from openbb_terminal.config.menu_text import RICH_TAGS
+from openbb_cli.config.menu_text import RICH_TAGS
if TYPE_CHECKING:
- from openbb_terminal.models.settings import Settings
+ from openbb_cli.models.settings import Settings
class Console:
@@ -19,11 +19,11 @@ class Console:
def __init__(
self,
settings: "Settings",
- style: Optional[str] = None,
+ style: Optional[Dict[str, Any]] = None,
):
"""Initialize the ConsoleAndPanel class."""
self._console = RichConsole(
- theme=Theme(style), # type: ignore[arg-type]
+ theme=Theme(style),
highlight=False,
soft_wrap=True,
)
diff --git a/openbb_terminal/openbb_terminal/config/constants.py b/cli/openbb_cli/config/constants.py
index 462dae59c0a..c44150324f3 100644
--- a/openbb_terminal/openbb_terminal/config/constants.py
+++ b/cli/openbb_cli/config/constants.py
@@ -6,13 +6,13 @@ from pathlib import Path
HOME_DIRECTORY = Path.home()
REPOSITORY_DIRECTORY = Path(__file__).parent.parent.parent.parent
SRC_DIRECTORY = Path(__file__).parent.parent
-SETTINGS_DIRECTORY = HOME_DIRECTORY / ".openbb_terminal"
+SETTINGS_DIRECTORY = HOME_DIRECTORY / ".openbb_platform"
ASSETS_DIRECTORY = SRC_DIRECTORY / "assets"
STYLES_DIRECTORY = ASSETS_DIRECTORY / "styles"
ENV_FILE_REPOSITORY = REPOSITORY_DIRECTORY / ".env"
-ENV_FILE_PROJECT = REPOSITORY_DIRECTORY / "openbb_terminal" / ".env"
-ENV_FILE_SETTINGS = SETTINGS_DIRECTORY / ".env"
-HIST_FILE_PROMPT = SETTINGS_DIRECTORY / ".openbb_terminal.his"
+ENV_FILE_PROJECT = REPOSITORY_DIRECTORY / "openbb_cli" / ".env"
+ENV_FILE_SETTINGS = SETTINGS_DIRECTORY / ".cli.env"
+HIST_FILE_PROMPT = SETTINGS_DIRECTORY / ".cli.his"
I18N_FILE = ASSETS_DIRECTORY / "i18n"
diff --git a/openbb_terminal/openbb_terminal/config/menu_text.py b/cli/openbb_cli/config/menu_text.py
index bd6234097d6..39bfa5787e9 100644
--- a/openbb_terminal/openbb_terminal/config/menu_text.py
+++ b/cli/openbb_cli/config/menu_text.py
@@ -50,7 +50,7 @@ def get_ordered_list_sources(command_path: str) -> List:
class MenuText:
- """Create menu text with rich colors to be displayed by terminal."""
+ """Create menu text with rich colors to be displayed by CLI."""
def __init__(self, path: str = "", column_sources: int = 100):
"""Initialize menu help.
diff --git a/openbb_terminal/openbb_terminal/config/setup.py b/cli/openbb_cli/config/setup.py
index c6547a62d59..09bbe505270 100644
--- a/openbb_terminal/openbb_terminal/config/setup.py
+++ b/cli/openbb_cli/config/setup.py
@@ -1,4 +1,4 @@
"""Configuration for the terminal."""
import copy
from pathlib import Path
@@ -6,7 +6,8 @@ from typing import TYPE_CHECKING, List, Optional, TypeVar
import i18n
-from openbb_terminal.config.constants import I18N_FILE
+from openbb_cli.config.constants import ENV_FILE_SETTINGS, I18N_FILE, SETTINGS_DIRECTORY
+from openbb_cli.session import Session
if TYPE_CHECKING:
from openbb_charting.core.openbb_figure import OpenBBFigure
@@ -70,15 +71,15 @@ def set_current_figure(fig: Optional[OpenBBFigureT] = None):
def setup_i18n(i18
@@ -1,4 +1,4 @@
-"""Configuration for the terminal."""
+"""Configuration for the CLI."""
import copy
from pathlib import Path